<section id="{{ wialonnotification.pk }}" hx-target="this" hx-indicator="#loading" class="p-4 flex flex-col gap-4 border rounded bg-gray-200">
    <section class="flex items-center justify-between">
        <h3 class="font-semibold">{{ wialonnotification.name }}</h3>
        <p>{{ wialonnotification.enabled|yesno:'Enabled,Disabled' }}</p>
    </section>
    <section id="buttons" class="flex flex-col gap-2">
        <button class="flex w-full cursor-pointer items-center justify-center gap-2 rounded border border-terminus-red-900 bg-terminus-red-800 p-2 text-center text-white transition-colors duration-300 ease-in-out hover:bg-terminus-red-400" hx-get="{% url 'terminusgps_notifications:update notifications' wialonnotification.pk %}" hx-trigger="click" type="button">Update</button>
        <a class="flex w-full cursor-pointer items-center justify-center gap-2 rounded border border-terminus-red-900 bg-terminus-red-800 p-2 text-center text-white transition-colors duration-300 ease-in-out hover:bg-terminus-red-400" href="{% url 'terminusgps_notifications:notifications' %}">Back</a>
    </section>
</section>
