<p hx-target="#notifications" hx-trigger="load delay:3s" hx-swap="outerHTML" hx-get="{{ redirect_url }}" hx-headers='{"HX-Push-Url": "{{ redirect_url }}", "HX-Refresh": "true"}'>Nice! You made {{ wialonnotification.name }}!</p>
