<a href="mailto:support@terminusgps.com" class="w-fit decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white">Email support@terminusgps.com</a>
