<footer class="w-full border-t border-gray-200 bg-stone-100 p-4 drop-shadow md:flex md:items-center md:justify-between md:p-6 dark:border-gray-600 dark:bg-zinc-600">
    <span class="text-sm text-gray-800 sm:text-center dark:text-gray-100">© 2025 <a href="https://terminusgps.com/" class="decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white">Terminus GPS, LLC</a>. All Rights Reserved.</span>
    <ul hx-boost="true" class="mt-3 flex flex-wrap items-center text-sm font-medium text-gray-600 sm:mt-0 dark:text-gray-400">
        <li><a href="{% url 'terminusgps_notifications:contact' %}" class="me-4 decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white md:me-6">Contact</a></li>
        <li><a href="{% url 'terminusgps_notifications:privacy' %}" class="me-4 decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white md:me-6">Privacy</a></li>
        <li><a href="{% url 'terminusgps_notifications:source code' %}" class="me-4 decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white md:me-6" hx-boost="false">Source</a></li>
        <li><a href="{% url 'terminusgps_notifications:terms' %}" class="me-4 decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white md:me-6">Terms</a></li>
    </ul>
</footer>
