<section id="notifications" class="flex flex-col gap-4">
    {% if not has_subscription %}
    <section id="notice" class="p-4 rounded border border-current bg-yellow-50 text-yellow-700 flex flex-col gap-2 items-center md:flex-row">
        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="size-8 fill-yellow-100 text-yellow-800 md:size-6">
            <path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126ZM12 15.75h.007v.008H12v-.008Z" />
        </svg>
        <p>Your notifications cannot be delivered without an active <a class="w-fit decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white" href="{% url 'terminusgps_notifications:subscription' %}" hx-boost="true">subscription</a>!</p>
    </section>
    {% endif %}
    <section id="notifications-list" class="flex flex-col gap-4" hx-target="this" hx-get="{% url 'terminusgps_notifications:list notifications' %}?refresh=true" hx-trigger="load once"></section>
</section>
